const fs = require("fs-extra");
const path = require("path");

const createStructure = (projectName, options) => {
  const rootPath = path.join(process.cwd(), projectName);

  let folders = ["controllers", "models", "router", "middlewares", "helpers"];

  if (options.addConfig) {
    folders.push("config");
  }

  folders.forEach((folder) => {
    fs.ensureDirSync(path.join(rootPath, folder));
  });

  // Create main index.js file
  const indexPath = path.join(rootPath, "index.js");
  const indexContent = `
const express = require('express');
const app = express();
const port = process.env.PORT || 3000;

app.use(express.json());
app.use(express.urlencoded({ extended: true }));

// Import routes
const routes = require('./routes');
app.use('/api', routes);

app.listen(port, () => {
  console.log(\`Server is running on port \${port}\`);
});
  `;
  fs.writeFileSync(indexPath, indexContent.trim());

  if (options.addConfig) {
    const configPath = path.join(rootPath, "config");
    const configContent = `
                module.exports = {
                port: process.env.PORT || 3000,
                db: {
                    host: process.env.DB_HOST || 'localhost',
                    port: process.env.DB_PORT || 27017,
                    name: process.env.DB_NAME || 'database_name'
                }
                };
  `;
    fs.writeFileSync(path.join(configPath, "config.js"), configContent.trim());

    const dbConfigContent = `
                const mongoose = require('mongoose');
                const config = require('./config');

                mongoose.connect(\`mongodb://\${config.db.host}:\${config.db.port}/\${config.db.name}\`, {
                useNewUrlParser: true,
                useUnifiedTopology: true
                }).then(() => {
                console.log('Connected to the database');
                }).catch((err) => {
                console.error('Database connection error:', err);
                });
  `;
    fs.writeFileSync(
      path.join(configPath, "dbConfig.js"),
      dbConfigContent.trim()
    );
  }

  // Create config files

  // Create .env file
  const envContent = `
            PORT=3000
            DB_HOST=localhost
            DB_PORT=27017
            DB_NAME=database_name
  `;
  fs.writeFileSync(path.join(rootPath, ".env"), envContent.trim());

  console.log(`Project structure for ${projectName} has been created.`);
};

module.exports = { createStructure };
